package com.zjsgfa.project.zjsgfa.service;

import java.util.List;
import com.zjsgfa.project.zjsgfa.domain.SjJkzp;

/**
 * 设计-井控专篇Service接口
 * 
 * @author ruoyi
 * @date 2025-07-24
 */
public interface ISjJkzpService 
{
    /**
     * 查询设计-井控专篇
     * 
     * @param id 设计-井控专篇主键
     * @return 设计-井控专篇
     */
    public SjJkzp selectSjJkzpById(Long id);

    /**
     * 查询设计-井控专篇列表
     * 
     * @param sjJkzp 设计-井控专篇
     * @return 设计-井控专篇集合
     */
    public List<SjJkzp> selectSjJkzpList(SjJkzp sjJkzp);

    /**
     * 新增设计-井控专篇
     * 
     * @param sjJkzp 设计-井控专篇
     * @return 结果
     */
    public int insertSjJkzp(SjJkzp sjJkzp);

    /**
     * 修改设计-井控专篇
     * 
     * @param sjJkzp 设计-井控专篇
     * @return 结果
     */
    public int updateSjJkzp(SjJkzp sjJkzp);

    /**
     * 批量删除设计-井控专篇
     * 
     * @param ids 需要删除的设计-井控专篇主键集合
     * @return 结果
     */
    public int deleteSjJkzpByIds(Long[] ids);

    /**
     * 删除设计-井控专篇信息
     * 
     * @param id 设计-井控专篇主键
     * @return 结果
     */
    public int deleteSjJkzpById(Long id);
}
